@@ -4,7 +4,7 @@ from sqlalchemy import String
 from sqlalchemy import ForeignKey
 from marshmallow import fields
 from marshmallow import Schema
-from marshmallow import pre_load
+from marshmallow import post_load
 
 from .base import Base
 
@@ -14,6 +14,7 @@ class Address(Base):
 
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
     user_id = Column(ForeignKey('users.id'), nullable=False)
+    name = Column(String(30), nullable=False)
     zip_code = Column(String(4), nullable=False)
     city = Column(String(25), nullable=False)
     address = Column(String(25), nullable=False)
@@ -25,14 +26,13 @@ class AddressSchema(Schema):
     model_class = Address
 
     id = fields.Integer()
-    user_id = fields.Integer(load_only=True)
-    zip_code = fields.String()
+    user_id = fields.Integer(load_only=True, data_key='userID')
+    name = fields.String()
+    zip_code = fields.String(data_key='zipCode')
     city = fields.String()
     address = fields.String()
     description = fields.String(allow_none=True)
 
-    @pre_load
-    def fix_zip_code(self, data, **kwargs):
-        data['zip_code'] = data['zipCode']
-        del data['zipCode']
-        return data
+    @post_load
+    def make_address(self, data, **kwargs):
+        return Address(**data)
